=========
Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <https://keepachangelog.com/en/1.0.0/>`_,
and this project adheres to a form of Semantic Versioning called
`Realistic (or Practical) Semantic Versioning <https://iscinumpy.dev/post/bound-version-constraints/>`_.

`0.0.1`_ (2025-09-16)
---------------------

Added
~~~~~

* First release on PyPI.

.. _`0.0.1`:https://github.com/ugognw/eldl/releases/tag/v0.0.1
